@@ -4,7 +4,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-02-14'; # DATE
 our $DIST = 'BorderStyles-Test'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 1;
 # ABSTRACT: A collection of border styles, mainly for testing
@@ -21,7 +21,17 @@ BorderStyles::Test - A collection of border styles, mainly for testing
 
 =head1 VERSION
 
-This document describes version 0.004 of BorderStyles::Test (from Perl distribution BorderStyles-Test), released on 2022-02-14.
+This document describes version 0.005 of BorderStyles::Test (from Perl distribution BorderStyles-Test), released on 2022-02-14.
+
+=head1 BORDER STYLES
+
+=over
+
+=item * L<BorderStyle::Test::Random>
+
+A border style that uses random characters.
+
+=back
 
 =head1 HOMEPAGE
 
@@ -31,6 +41,14 @@ Please visit the project's homepage at L<https://metacpan.org/release/BorderStyl
 
 Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Test>.
 
+=head1 SEE ALSO
+
+L<BorderStyle> - specification
+
+L<App::BorderStyleUtils> - CLIs
+
+L<Text::Table::TinyBorderStyle>, L<Text::ANSITable> - some table renderers that can use border styles
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
